@@ -1,3 +1,3 @@
 from .file_filters import *
 from .initFuncGen import *
-from .import_utils import ifFunctionsInFiles
+from .import_utils import *
