@@ -88,6 +88,8 @@ MIME_TYPES = {
         '.wmv':   'video/x-ms-wmv',
         '.3gp':   'video/3gpp',
         '.ts':    'video/mp2t',
+        '.mpeg':  'video/mpeg',
+        '.mpg':   'video/mpg'
     },
     'audio': {
         '.mp3':   'audio/mpeg',
@@ -216,10 +218,11 @@ def get_media_exts(categories=None):
     return sorted({ext for exts in media_map.values() for ext in exts})
 
 
-def confirm_type(path_or_ext, categories=None):
+def confirm_type(path_or_ext, categories=None,**kwargs):
     """
     Given a file‐path or extension, return its media category (e.g. "image"), or None.
     """
+    categories = categories or kwargs.get('media_types')
     ext = Path(path_or_ext).suffix.lower()
     media_map = get_media_map(categories)
     for category, exts in media_map.items():
@@ -228,10 +231,11 @@ def confirm_type(path_or_ext, categories=None):
     return None
 
 
-def is_media_type(path_or_ext, categories):
+def is_media_type(path_or_ext, categories=None,**kwargs):
     """
     True if the given file‐path or extension belongs to one of the categories.
     """
+    categories = categories or kwargs.get('media_types')
     return confirm_type(path_or_ext, categories) is not None
 
 
@@ -246,11 +250,12 @@ def get_mime_type(path_or_ext):
     return 'application/octet-stream'
 
 
-def get_all_file_types(categories, directory):
+def get_all_file_types(categories=None, directory=None,**kwargs):
     """
     Recursively glob for files under `directory` whose extension belongs to `categories`.
     Returns a list of full paths.
     """
+    categories = categories or kwargs.get('media_types')
     base = Path(directory)
     if not base.is_dir():
         return []
